@@ -79,12 +79,17 @@ class Config:
             )
             Config.DB_URI = "sqlite:///" + sqlite_path
         else:
-            base = Config.DB_MODE.upper() + "_"
+            base = Config.DB_MODE.upper()
+            db_keyword = "DATABASE"
+            if base == "POSTGRESQL":
+                base = "POSTGRES"
+                db_keyword = "DB"
+            base += "_"
             db_host = os.environ[base + "HOST"]
             db_port = os.environ[base + "PORT"]
             db_user = os.environ[base + "USER"]
             db_password = os.environ[base + "PASSWORD"]
-            db_database = os.environ[base + "DATABASE"]
+            db_database = os.environ[base + db_keyword]
             Config.DB_URI = f"{Config.DB_MODE}://{db_user}:{db_password}@"\
                             f"{db_host}:{db_port}/{db_database}"
 
@@ -150,18 +155,16 @@ class Config:
             optional.append("SQLITE_PATH")
         elif db_mode is not None:
             db_mode = db_mode.upper()
+            db_keyword = "DATABASE"
+            if db_mode == "POSTGRESQL":
+                db_mode = "POSTGRES"
+                db_keyword = "DB"
+
             required.append(f"{db_mode}_HOST")
             required.append(f"{db_mode}_PORT")
             required.append(f"{db_mode}_USER")
             required.append(f"{db_mode}_PASSWORD")
-            required.append(f"{db_mode}_DATABASE")
-
-            if db_mode == "POSTGRESQL":
-                required += [
-                    "POSTGRES_USER",
-                    "POSTGRES_PASSWORD",
-                    "POSTGRES_DB"
-                ]
+            required.append(f"{db_mode}_{db_keyword}")
 
         return {
             "required": required,
